.. role:: hidden
    :class: hidden-section

Vizualisaton
============

.. automodule:: pyeeg.vizu
    :no-members:
    :no-inherited-members:

Functions
---------

.. autosummary:: 
    :toctree: generated/
    :template: function.rst

    pyeeg.vizu.significance_overlay
    pyeeg.vizu.pairwise_boxplots
    pyeeg.vizu.plot_interactive
    pyeeg.vizu.topomap
    pyeeg.vizu.get_spatial_colors
    pyeeg.vizu.colormap_masked
    pyeeg.vizu.plot_trf_signi
    pyeeg.vizu.plot_filterbank
    pyeeg.vizu.plot_filterbank_output
    pyeeg.vizu.topoplot_array
    pyeeg.vizu.plots_topogrid
